@@ -371,6 +371,8 @@ class RobustDPatch(EvasionAttack):
         if self.targeted:
             predictions = y_copy
         else:
+            if channels_first:
+                x_copy = np.transpose(x_copy, (0, 3, 1, 2))
             predictions = self.estimator.predict(x=x_copy, standardise_output=True)
 
         for i_image in range(x_copy.shape[0]):
@@ -413,8 +415,12 @@ class RobustDPatch(EvasionAttack):
         # Account for cropping when considering the upper left point of the patch:
         x_1 = self.patch_location[0] - int(transforms["crop_x"])
         y_1 = self.patch_location[1] - int(transforms["crop_y"])
-        x_2 = x_1 + self.patch_shape[0]
-        y_2 = y_1 + self.patch_shape[1]
+        if channels_first:
+            x_2 = x_1 + self.patch_shape[1]
+            y_2 = y_1 + self.patch_shape[2]
+        else:
+            x_2 = x_1 + self.patch_shape[0]
+            y_2 = y_1 + self.patch_shape[1]
         gradients = gradients[:, x_1:x_2, y_1:y_2, :]
 
         if channels_first:
