@@ -22,7 +22,7 @@ The Pixel Attack is a generalisation of One Pixel Attack.
 | One Pixel Attack Paper link: https://arxiv.org/ans/1710.08864
 | Pixel and Threshold Attack Paper link: https://arxiv.org/abs/1906.06026
 """
-# pylint: disable=C0302
+# pylint: disable=C0302,C0413
 from __future__ import absolute_import, division, print_function, unicode_literals
 
 import logging
@@ -39,16 +39,22 @@ import numpy as np
 # Otherwise may use Tensorflow's implementation of DE.
 
 from six import string_types
+import scipy
 from scipy._lib._util import check_random_state
-from scipy.optimize.optimize import _status_message
-from scipy.optimize import OptimizeResult, minimize
-from tqdm.auto import tqdm
 
-from art.config import ART_NUMPY_DTYPE
-from art.attacks.attack import EvasionAttack
-from art.estimators.estimator import BaseEstimator, NeuralNetworkMixin
-from art.estimators.classification.classifier import ClassifierMixin
-from art.utils import compute_success, to_categorical, check_and_transform_label_format
+scipy_version = list(map(int, scipy.__version__.lower().split(".")))
+if scipy_version[1] >= 8:
+    from scipy.optimize._optimize import _status_message  # pylint: disable=E0611
+else:
+    from scipy.optimize.optimize import _status_message  # pylint: disable=E0611
+from scipy.optimize import OptimizeResult, minimize  # noqa
+from tqdm.auto import tqdm  # noqa
+
+from art.config import ART_NUMPY_DTYPE  # noqa
+from art.attacks.attack import EvasionAttack  # noqa
+from art.estimators.estimator import BaseEstimator, NeuralNetworkMixin  # noqa
+from art.estimators.classification.classifier import ClassifierMixin  # noqa
+from art.utils import check_and_transform_label_format  # noqa
 
 if TYPE_CHECKING:
     from art.utils import CLASSIFIER_NEURALNETWORK_TYPE
@@ -97,6 +103,7 @@ class PixelThreshold(EvasionAttack):
         self._targeted = targeted
         self.verbose = verbose
         self.verbose_es = verbose_es
+        self.rescale = False
         PixelThreshold._check_params(self)
 
         if self.estimator.channels_first:
@@ -145,7 +152,8 @@ class PixelThreshold(EvasionAttack):
         :param max_iter: Maximum number of optimisation iterations.
         :return: An array holding the adversarial examples.
         """
-        y = check_and_transform_label_format(y, self.estimator.nb_classes, return_one_hot=False)
+        if y is not None:
+            y = check_and_transform_label_format(y, self.estimator.nb_classes, return_one_hot=False)
 
         if y is None:
             if self.targeted:
@@ -159,7 +167,7 @@ class PixelThreshold(EvasionAttack):
             if y.ndim > 1 and y.shape[1] > 1:
                 y = np.argmax(y, axis=1)
 
-        y = np.squeeze(y)
+        y = np.squeeze(y)  # type: ignore
 
         if self.th is None:
             logger.info(
@@ -182,7 +190,7 @@ class PixelThreshold(EvasionAttack):
 
         adv_x_best = []
         self.adv_th = []
-        for image, target_class in tqdm(zip(x, y), desc="Pixel threshold", disable=not self.verbose):
+        for image, target_class in tqdm(zip(x, y), desc="Pixel threshold", disable=not self.verbose):  # type: ignore
 
             if self.th is None:
 
@@ -219,17 +227,9 @@ class PixelThreshold(EvasionAttack):
 
         adv_x_best_array = np.array(adv_x_best)
 
-        if y is not None:
-            y = to_categorical(y, self.estimator.nb_classes)
-
         if self.rescale:
-            x = self.rescale_input(x)
             adv_x_best_array = self.rescale_input(adv_x_best_array)
 
-        logger.info(
-            "Success rate of Attack: %.2f%%",
-            100 * compute_success(self.estimator, x, y, adv_x_best_array, self.targeted, 1),
-        )
         return adv_x_best_array
 
     def _get_bounds(self, img: np.ndarray, limit) -> Tuple[List[list], list]:
@@ -405,7 +405,7 @@ class PixelAttack(PixelThreshold):
         """
         Define the bounds for the image `img` within the limits `limit`.
         """
-        initial: List[np.ndarray] = []
+        initial: List[int] = []
         bounds: List[List[int]]
         if self.es == 0:
             for count, (i, j) in enumerate(product(range(self.img_rows), range(self.img_cols))):
@@ -1209,7 +1209,7 @@ class DifferentialEvolutionSolver:  # pragma: no cover
                 break
 
             if self.disp:
-                print("differential_evolution step %d: f(x)= %g" % (nit, self.population_energies[0]))
+                print(f"differential_evolution step {nit}: f(x)= {self.population_energies[0]}")
 
             # should the solver terminate?
             convergence = self.convergence
