@@ -43,9 +43,10 @@ from art.attacks.evasion.projected_gradient_descent.projected_gradient_descent_p
 from art.attacks.evasion.projected_gradient_descent.projected_gradient_descent_tensorflow_v2 import (
     ProjectedGradientDescentTensorFlowV2,
 )
+from art.summary_writer import SummaryWriter
 
 if TYPE_CHECKING:
-    from art.utils import CLASSIFIER_LOSS_GRADIENTS_TYPE
+    from art.utils import CLASSIFIER_LOSS_GRADIENTS_TYPE, OBJECT_DETECTOR_TYPE
 
 logger = logging.getLogger(__name__)
 
@@ -68,6 +69,7 @@ class ProjectedGradientDescent(EvasionAttack):
         "batch_size",
         "max_iter",
         "random_eps",
+        "summary_writer",
         "verbose",
     ]
 
@@ -75,7 +77,7 @@ class ProjectedGradientDescent(EvasionAttack):
 
     def __init__(
         self,
-        estimator: "CLASSIFIER_LOSS_GRADIENTS_TYPE",
+        estimator: Union["CLASSIFIER_LOSS_GRADIENTS_TYPE", "OBJECT_DETECTOR_TYPE"],
         norm: Union[int, float, str] = np.inf,
         eps: Union[int, float, np.ndarray] = 0.3,
         eps_step: Union[int, float, np.ndarray] = 0.1,
@@ -84,6 +86,7 @@ class ProjectedGradientDescent(EvasionAttack):
         num_random_init: int = 0,
         batch_size: int = 32,
         random_eps: bool = False,
+        summary_writer: Union[str, bool, SummaryWriter] = False,
         verbose: bool = True,
     ):
         """
@@ -102,9 +105,16 @@ class ProjectedGradientDescent(EvasionAttack):
         :param num_random_init: Number of random initialisations within the epsilon ball. For num_random_init=0 starting
                                 at the original input.
         :param batch_size: Size of the batch on which adversarial samples are generated.
+        :param summary_writer: Activate summary writer for TensorBoard.
+                               Default is `False` and deactivated summary writer.
+                               If `True` save runs/CURRENT_DATETIME_HOSTNAME in current directory.
+                               If of type `str` save in path.
+                               If of type `SummaryWriter` apply provided custom summary writer.
+                               Use hierarchical folder structure to compare between runs easily. e.g. pass in
+                               ‘runs/exp1’, ‘runs/exp2’, etc. for each new experiment to compare across them.
         :param verbose: Show progress bars.
         """
-        super().__init__(estimator=estimator)
+        super().__init__(estimator=estimator, summary_writer=False)
 
         self.norm = norm
         self.eps = eps
@@ -131,6 +141,7 @@ class ProjectedGradientDescent(EvasionAttack):
                 num_random_init=num_random_init,
                 batch_size=batch_size,
                 random_eps=random_eps,
+                summary_writer=summary_writer,
                 verbose=verbose,
             )
 
@@ -145,6 +156,7 @@ class ProjectedGradientDescent(EvasionAttack):
                 num_random_init=num_random_init,
                 batch_size=batch_size,
                 random_eps=random_eps,
+                summary_writer=summary_writer,
                 verbose=verbose,
             )
 
@@ -159,6 +171,7 @@ class ProjectedGradientDescent(EvasionAttack):
                 num_random_init=num_random_init,
                 batch_size=batch_size,
                 random_eps=random_eps,
+                summary_writer=summary_writer,
                 verbose=verbose,
             )
 
@@ -180,26 +193,37 @@ class ProjectedGradientDescent(EvasionAttack):
         logger.info("Creating adversarial samples.")
         return self._attack.generate(x=x, y=y, **kwargs)
 
+    @property
+    def summary_writer(self):
+        """The summary writer."""
+        return self._attack.summary_writer
+
     def set_params(self, **kwargs) -> None:
         super().set_params(**kwargs)
         self._attack.set_params(**kwargs)
 
     def _check_params(self) -> None:
-        # Check if order of the norm is acceptable given current implementation
+
         if self.norm not in [1, 2, np.inf, "inf"]:
             raise ValueError('Norm order must be either 1, 2, `np.inf` or "inf".')
 
-        if not (isinstance(self.eps, (int, float, np.ndarray)) and isinstance(self.eps_step, (int, float, np.ndarray))):
+        if not (
+            isinstance(self.eps, (int, float))
+            and isinstance(self.eps_step, (int, float))
+            or isinstance(self.eps, np.ndarray)
+            and isinstance(self.eps_step, np.ndarray)
+        ):
             raise TypeError(
-                "The perturbation size `eps` and the perturbation step-size `eps_step` must have the same type."
+                "The perturbation size `eps` and the perturbation step-size `eps_step` must have the same type of `int`"
+                ", `float`, or `np.ndarray`."
             )
 
         if isinstance(self.eps, (int, float)):
-            if self.eps <= 0:
-                raise ValueError("The perturbation size `eps` has to be positive.")
+            if self.eps < 0:
+                raise ValueError("The perturbation size `eps` has to be nonnegative.")
         else:
-            if (self.eps <= 0).any():
-                raise ValueError("The perturbation size `eps` has to be positive.")
+            if (self.eps < 0).any():
+                raise ValueError("The perturbation size `eps` has to be nonnegative.")
 
         if isinstance(self.eps_step, (int, float)):
             if self.eps_step <= 0:
@@ -214,17 +238,10 @@ class ProjectedGradientDescent(EvasionAttack):
                     "The perturbation size `eps` and the perturbation step-size `eps_step` must have the same shape."
                 )
 
-            if self.norm in ["inf", np.inf] and (self.eps_step > self.eps).any():
-                raise ValueError("The iteration step `eps_step` has to be smaller than the total attack `eps`.")
-
-        else:
-            if self.norm in ["inf", np.inf] and self.eps_step > self.eps:
-                raise ValueError("The iteration step `eps_step` has to be smaller than the total attack `eps`.")
-
         if not isinstance(self.targeted, bool):
             raise ValueError("The flag `targeted` has to be of type bool.")
 
-        if not isinstance(self.num_random_init, (int, np.int)):
+        if not isinstance(self.num_random_init, int):
             raise TypeError("The number of random initialisations has to be of type integer.")
 
         if self.num_random_init < 0:
@@ -233,8 +250,8 @@ class ProjectedGradientDescent(EvasionAttack):
         if self.batch_size <= 0:
             raise ValueError("The batch size `batch_size` has to be positive.")
 
-        if self.max_iter <= 0:
-            raise ValueError("The number of iterations `max_iter` has to be a positive integer.")
+        if self.max_iter < 0:
+            raise ValueError("The number of iterations `max_iter` has to be a nonnegative integer.")
 
         if not isinstance(self.verbose, bool):
             raise ValueError("The verbose has to be a Boolean.")
