@@ -4,4 +4,5 @@ Module implementing train-based defences against adversarial attacks.
 from art.defences.trainer.trainer import Trainer
 from art.defences.trainer.adversarial_trainer import AdversarialTrainer
 from art.defences.trainer.adversarial_trainer_madry_pgd import AdversarialTrainerMadryPGD
-from art.defences.trainer.adversarial_trainer_FBF_Pytorch import AdversarialTrainerFBF, AdversarialTrainerFBFPyTorch
+from art.defences.trainer.adversarial_trainer_fbf import AdversarialTrainerFBF
+from art.defences.trainer.adversarial_trainer_fbf_pytorch import AdversarialTrainerFBFPyTorch
