@@ -7,8 +7,9 @@ from art.estimators.classification.classifier import (
     ClassGradientsMixin,
 )
 
-from art.estimators.classification.blackbox import BlackBoxClassifier
+from art.estimators.classification.blackbox import BlackBoxClassifier, BlackBoxClassifierNeuralNetwork
 from art.estimators.classification.catboost import CatBoostARTClassifier
+from art.estimators.classification.deep_partition_ensemble import DeepPartitionEnsemble
 from art.estimators.classification.detector_classifier import DetectorClassifier
 from art.estimators.classification.ensemble import EnsembleClassifier
 from art.estimators.classification.GPy import GPyGaussianProcessClassifier
@@ -16,6 +17,7 @@ from art.estimators.classification.keras import KerasClassifier
 from art.estimators.classification.lightgbm import LightGBMClassifier
 from art.estimators.classification.mxnet import MXClassifier
 from art.estimators.classification.pytorch import PyTorchClassifier
+from art.estimators.classification.query_efficient_bb import QueryEfficientGradientEstimationClassifier
 from art.estimators.classification.scikitlearn import SklearnClassifier
 from art.estimators.classification.tensorflow import (
     TFClassifier,
