@@ -38,7 +38,7 @@ from art.utils import check_and_transform_label_format
 
 if TYPE_CHECKING:
     # pylint: disable=C0412
-    import tensorflow as tf
+    import tensorflow.compat.v1 as tf
 
     from art.utils import CLIP_VALUES_TYPE, PREPROCESSING_TYPE
     from art.data_generators import DataGenerator
@@ -112,7 +112,7 @@ class TensorFlowClassifier(ClassGradientsMixin, ClassifierMixin, TensorFlowEstim
                           additionally required placeholders except the placeholders defined in this class.
         """
         # pylint: disable=E0401
-        import tensorflow as tf  # lgtm [py/repeated-import]
+        import tensorflow.compat.v1 as tf  # lgtm [py/repeated-import]
 
         super().__init__(
             model=None,
@@ -132,7 +132,7 @@ class TensorFlowClassifier(ClassGradientsMixin, ClassifierMixin, TensorFlowEstim
         self._loss = loss
         self._learning = learning
         if feed_dict is None:
-            self._feed_dict = dict()
+            self._feed_dict = {}
         else:
             self._feed_dict = feed_dict
 
@@ -388,7 +388,7 @@ class TensorFlowClassifier(ClassGradientsMixin, ClassifierMixin, TensorFlowEstim
                 and label.shape[0] == x.shape[0]
             )
         ):
-            raise ValueError("Label %s is out of range." % label)
+            raise ValueError(f"Label {label} is out of range.")
 
         self._init_class_grads(label=label)
 
@@ -477,7 +477,7 @@ class TensorFlowClassifier(ClassGradientsMixin, ClassifierMixin, TensorFlowEstim
         :return: Loss values.
         :rtype: Format as expected by the `model`
         """
-        import tensorflow as tf  # lgtm [py/repeated-import]
+        import tensorflow.compat.v1 as tf  # lgtm [py/repeated-import]
 
         if self.learning is not None:
             self.feed_dict[self.learning] = False
@@ -506,7 +506,7 @@ class TensorFlowClassifier(ClassGradientsMixin, ClassifierMixin, TensorFlowEstim
 
     def _init_class_grads(self, label=None):
         # pylint: disable=E0401
-        import tensorflow as tf  # lgtm [py/repeated-import]
+        import tensorflow.compat.v1 as tf  # lgtm [py/repeated-import]
 
         if not hasattr(self, "_class_grads"):
             self._class_grads = [None for _ in range(self.nb_classes)]
@@ -532,7 +532,7 @@ class TensorFlowClassifier(ClassGradientsMixin, ClassifierMixin, TensorFlowEstim
         :return: The hidden layers in the model, input and output layers excluded.
         """
         # pylint: disable=E0401
-        import tensorflow as tf  # lgtm [py/repeated-import]
+        import tensorflow.compat.v1 as tf  # lgtm [py/repeated-import]
 
         # Get the computational graph
         with self._sess.graph.as_default():
@@ -582,7 +582,7 @@ class TensorFlowClassifier(ClassGradientsMixin, ClassifierMixin, TensorFlowEstim
         :return: The output of `layer`, where the first dimension is the batch size corresponding to `x`.
         """
         # pylint: disable=E0401
-        import tensorflow as tf  # lgtm [py/repeated-import]
+        import tensorflow.compat.v1 as tf  # lgtm [py/repeated-import]
 
         if self.learning is not None:
             self.feed_dict[self.learning] = False
@@ -593,14 +593,14 @@ class TensorFlowClassifier(ClassGradientsMixin, ClassifierMixin, TensorFlowEstim
 
         if isinstance(layer, six.string_types):  # basestring for Python 2 (str, unicode) support
             if layer not in self._layer_names:  # pragma: no cover
-                raise ValueError("Layer name %s is not part of the graph." % layer)
+                raise ValueError(f"Layer name {layer} is not part of the graph.")
             layer_tensor = graph.get_tensor_by_name(layer)
 
         elif isinstance(layer, int):
             layer_tensor = graph.get_tensor_by_name(self._layer_names[layer])
 
         else:  # pragma: no cover
-            raise TypeError("Layer must be of type `str` or `int`. Received %s." % layer)
+            raise TypeError(f"Layer must be of type `str` or `int`. Received {layer}.")
 
         if framework:
             return layer_tensor
@@ -626,9 +626,9 @@ class TensorFlowClassifier(ClassGradientsMixin, ClassifierMixin, TensorFlowEstim
             layer_output = self._sess.run(layer_tensor, feed_dict=feed_dict)
             results.append(layer_output)
 
-        results = np.concatenate(results)
+        results_array = np.concatenate(results)
 
-        return results
+        return results_array
 
     def save(self, filename: str, path: Optional[str] = None) -> None:
         """
@@ -716,7 +716,7 @@ class TensorFlowClassifier(ClassGradientsMixin, ClassifierMixin, TensorFlowEstim
 
         # Load and update all functionality related to TensorFlow
         # pylint: disable=E0611, E0401
-        import tensorflow as tf  # lgtm [py/repeated-import]
+        import tensorflow.compat.v1 as tf  # lgtm [py/repeated-import]
         from tensorflow.python.saved_model import tag_constants
 
         full_path = os.path.join(config.ART_DATA_PATH, state["model_name"])
@@ -767,24 +767,11 @@ class TensorFlowClassifier(ClassGradientsMixin, ClassifierMixin, TensorFlowEstim
 
     def __repr__(self):
         repr_ = (
-            "%s(input_ph=%r, output=%r, labels_ph=%r, train=%r, loss=%r, learning=%r, sess=%r, "
-            "channels_first=%r, clip_values=%r, preprocessing_defences=%r, postprocessing_defences=%r, "
-            "preprocessing=%r)"
-            % (
-                self.__module__ + "." + self.__class__.__name__,
-                self.input_ph,
-                self.output,
-                self.labels_ph,
-                self.train,
-                self._loss,
-                self.learning,
-                self._sess,
-                self.channels_first,
-                self.clip_values,
-                self.preprocessing_defences,
-                self.postprocessing_defences,
-                self.preprocessing,
-            )
+            f"{self.__module__ + '.' + self.__class__.__name__}(input_ph={self.input_ph!r}, output={self.output!r}, "
+            f"labels_ph={self.labels_ph!r}, train={self.train!r}, loss={self._loss!r}, learning={self.learning!r}, "
+            f"sess={self._sess!r}, channels_first={self.channels_first}, clip_values={self.clip_values!r}, "
+            f"preprocessing_defences={self.preprocessing_defences}, "
+            f"postprocessing_defences={self.postprocessing_defences}, preprocessing={self.preprocessing})"
         )
 
         return repr_
@@ -1052,7 +1039,7 @@ class TensorFlowV2Classifier(ClassGradientsMixin, ClassifierMixin, TensorFlowV2E
             if tf.executing_eagerly():
                 if label is None:
                     # Compute the gradients w.r.t. all classes
-                    class_gradients = list()
+                    class_gradients = []
 
                     for i in range(self.nb_classes):
                         predictions = self.model(x_input, training=training_mode)
@@ -1078,7 +1065,7 @@ class TensorFlowV2Classifier(ClassGradientsMixin, ClassifierMixin, TensorFlowV2E
 
                 else:
                     # For each sample, compute the gradients w.r.t. the indicated target class (possibly distinct)
-                    class_gradients = list()
+                    class_gradients = []
                     unique_labels = list(np.unique(label))
 
                     for unique_label in unique_labels:
@@ -1107,7 +1094,7 @@ class TensorFlowV2Classifier(ClassGradientsMixin, ClassifierMixin, TensorFlowV2E
         y: Union[np.ndarray, "tf.Tensor"],
         reduction: str = "none",
         training_mode: bool = False,
-        **kwargs
+        **kwargs,
     ) -> np.ndarray:
         """
         Compute the loss.
@@ -1175,7 +1162,7 @@ class TensorFlowV2Classifier(ClassGradientsMixin, ClassifierMixin, TensorFlowV2E
         x: Union[np.ndarray, "tf.Tensor"],
         y: Union[np.ndarray, "tf.Tensor"],
         training_mode: bool = False,
-        **kwargs
+        **kwargs,
     ) -> Union[np.ndarray, "tf.Tensor"]:
         """
         Compute the gradient of the loss function w.r.t. `x`.
@@ -1326,7 +1313,7 @@ class TensorFlowV2Classifier(ClassGradientsMixin, ClassifierMixin, TensorFlowV2E
 
         return None  # type: ignore
 
-    def get_activations(
+    def get_activations(  # type: ignore
         self, x: np.ndarray, layer: Union[int, str], batch_size: int = 128, framework: bool = False
     ) -> Optional[np.ndarray]:
         """
@@ -1337,6 +1324,7 @@ class TensorFlowV2Classifier(ClassGradientsMixin, ClassifierMixin, TensorFlowV2E
         :param x: Input for computing the activations.
         :param layer: Layer for computing the activations.
         :param batch_size: Batch size.
+        :param framework: Return activation as tensor.
         :return: The output of `layer`, where the first dimension is the batch size corresponding to `x`.
         """
         import tensorflow as tf  # lgtm [py/repeated-import]
@@ -1351,7 +1339,7 @@ class TensorFlowV2Classifier(ClassGradientsMixin, ClassifierMixin, TensorFlowV2E
 
         if isinstance(layer, six.string_types):
             if layer not in self.layer_names:  # pragma: no cover
-                raise ValueError("Layer name %s is not part of the graph." % layer)
+                raise ValueError(f"Layer name {layer} is not part of the graph.")
             for i_name, name in enumerate(self.layer_names):
                 if name == layer:
                     i_layer = i_name
@@ -1359,8 +1347,8 @@ class TensorFlowV2Classifier(ClassGradientsMixin, ClassifierMixin, TensorFlowV2E
         elif isinstance(layer, int):
             if layer < -len(self.layer_names) or layer >= len(self.layer_names):  # pragma: no cover
                 raise ValueError(
-                    "Layer index %d is outside of range (-%d to %d)."
-                    % (layer, len(self.layer_names), len(self.layer_names) - 1)
+                    f"Layer index {layer} is outside of range (-{len(self.layer_names)} "
+                    f"to {len(self.layer_names) - 1})."
                 )
             i_layer = layer
         else:  # pragma: no cover
@@ -1368,14 +1356,14 @@ class TensorFlowV2Classifier(ClassGradientsMixin, ClassifierMixin, TensorFlowV2E
 
         activation_model = tf.keras.Model(self._model.layers[0].input, self._model.layers[i_layer].output)
 
-        if framework:
-            if isinstance(x, tf.Tensor):
-                return activation_model(x, training=False)
-            return activation_model(tf.convert_to_tensor(x), training=False)
-
         # Apply preprocessing
         x_preprocessed, _ = self._apply_preprocessing(x=x, y=None, fit=False)
 
+        if framework:
+            if isinstance(x_preprocessed, tf.Tensor):
+                return activation_model(x_preprocessed, training=False)
+            return activation_model(tf.convert_to_tensor(x_preprocessed), training=False)
+
         # Determine shape of expected output and prepare array
         output_shape = self._model.layers[i_layer].output_shape
         activations = np.zeros((x_preprocessed.shape[0],) + output_shape[1:], dtype=ART_NUMPY_DTYPE)
@@ -1402,22 +1390,11 @@ class TensorFlowV2Classifier(ClassGradientsMixin, ClassifierMixin, TensorFlowV2E
 
     def __repr__(self):
         repr_ = (
-            "%s(model=%r, nb_classes=%r, input_shape=%r, loss_object=%r, train_step=%r, "
-            "channels_first=%r, clip_values=%r, preprocessing_defences=%r, postprocessing_defences=%r, "
-            "preprocessing=%r)"
-            % (
-                self.__module__ + "." + self.__class__.__name__,
-                self._model,
-                self.nb_classes,
-                self._input_shape,
-                self._loss_object,
-                self._train_step,
-                self.channels_first,
-                self.clip_values,
-                self.preprocessing_defences,
-                self.postprocessing_defences,
-                self.preprocessing,
-            )
+            f"{self.__module__ + '.' + self.__class__.__name__}(model={self._model}, nb_classes={self.nb_classes}, "
+            f"input_shape={self._input_shape}, loss_object={self._loss_object}, train_step={self._train_step}, "
+            f"channels_first={self.channels_first}, clip_values={self.clip_values!r}, "
+            f"preprocessing_defences={self.preprocessing_defences}, "
+            f"postprocessing_defences={self.postprocessing_defences}, preprocessing={self.preprocessing})"
         )
 
         return repr_
