@@ -19,19 +19,27 @@ from __future__ import absolute_import, division, print_function, unicode_litera
 
 import logging
 import unittest
-import keras
-import keras.backend as k
+
+# import keras
+# import keras.backend as k
 import numpy as np
 
-from art.attacks.evasion.carlini import CarliniL2Method, CarliniLInfMethod
-from art.estimators.classification.keras import KerasClassifier
+from art.attacks.evasion.carlini import CarliniL0Method, CarliniL2Method, CarliniLInfMethod
+
+# from art.estimators.classification.keras import KerasClassifier
 from art.estimators.estimator import BaseEstimator
 from art.estimators.classification.classifier import ClassGradientsMixin
-from art.utils import random_targets, to_categorical
+from art.utils import random_targets
+
+# from art.utils import to_categorical
 
 from tests.utils import TestBase, master_seed
-from tests.utils import get_image_classifier_tf, get_image_classifier_kr, get_image_classifier_pt
-from tests.utils import get_tabular_classifier_tf, get_tabular_classifier_kr, get_tabular_classifier_pt
+from tests.utils import get_image_classifier_tf
+
+from tests.utils import get_image_classifier_pt
+
+# from test.utils import get_image_classifier_kr
+# from tests.utils import get_tabular_classifier_tf, get_tabular_classifier_kr, get_tabular_classifier_pt
 from tests.attacks.utils import backend_test_classifier_type_check_fail
 
 logger = logging.getLogger(__name__)
@@ -69,7 +77,13 @@ class TestCarlini(TestBase):
 
         # Failure attack
         cl2m = CarliniL2Method(
-            classifier=tfc, targeted=True, max_iter=0, binary_search_steps=0, learning_rate=0, initial_const=1
+            classifier=tfc,
+            targeted=True,
+            max_iter=0,
+            binary_search_steps=0,
+            learning_rate=0,
+            initial_const=1,
+            verbose=False,
         )
         params = {"y": random_targets(self.y_test_mnist, tfc.nb_classes)}
         x_test_adv = cl2m.generate(self.x_test_mnist, **params)
@@ -95,7 +109,7 @@ class TestCarlini(TestBase):
         tfc, sess = get_image_classifier_tf(from_logits=True)
 
         # First attack
-        cl2m = CarliniL2Method(classifier=tfc, targeted=True, max_iter=10)
+        cl2m = CarliniL2Method(classifier=tfc, targeted=True, max_iter=10, verbose=False)
         params = {"y": random_targets(self.y_test_mnist, tfc.nb_classes)}
         x_test_adv = cl2m.generate(self.x_test_mnist, **params)
         self.assertFalse((self.x_test_mnist == x_test_adv).all())
@@ -109,7 +123,7 @@ class TestCarlini(TestBase):
         self.assertTrue((target == y_pred_adv).any())
 
         # Second attack, no batching
-        cl2m = CarliniL2Method(classifier=tfc, targeted=False, max_iter=10, batch_size=1)
+        cl2m = CarliniL2Method(classifier=tfc, targeted=False, max_iter=10, batch_size=1, verbose=False)
         x_test_adv = cl2m.generate(self.x_test_mnist)
         self.assertLessEqual(np.amax(x_test_adv), 1.0)
         self.assertGreaterEqual(np.amin(x_test_adv), 0.0)
@@ -142,7 +156,7 @@ class TestCarlini(TestBase):
     #     krc = get_image_classifier_kr(from_logits=True)
     #
     #     # First attack
-    #     cl2m = CarliniL2Method(classifier=krc, targeted=True, max_iter=10)
+    #     cl2m = CarliniL2Method(classifier=krc, targeted=True, max_iter=10, verbose=False)
     #     y_target = [6, 6, 7, 4, 9, 7, 9, 0, 1, 0]
     #     x_test_adv = cl2m.generate(self.x_test_mnist, y=to_categorical(y_target, nb_classes=10))
     #     self.assertFalse((self.x_test_mnist == x_test_adv).all())
@@ -155,7 +169,7 @@ class TestCarlini(TestBase):
     #     self.assertTrue((y_target == y_pred_adv).any())
     #
     #     # Second attack
-    #     cl2m = CarliniL2Method(classifier=krc, targeted=False, max_iter=10)
+    #     cl2m = CarliniL2Method(classifier=krc, targeted=False, max_iter=10, verbose=False)
     #     x_test_adv = cl2m.generate(self.x_test_mnist)
     #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
     #     self.assertGreaterEqual(np.amin(x_test_adv), 0.0)
@@ -183,7 +197,7 @@ class TestCarlini(TestBase):
     #     ptc = get_image_classifier_pt(from_logits=True)
     #
     #     # First attack
-    #     cl2m = CarliniL2Method(classifier=ptc, targeted=True, max_iter=10)
+    #     cl2m = CarliniL2Method(classifier=ptc, targeted=True, max_iter=10, verbose=False)
     #     params = {"y": random_targets(self.y_test_mnist, ptc.nb_classes)}
     #     x_test_adv = cl2m.generate(x_test, **params)
     #     self.assertFalse((x_test == x_test_adv).all())
@@ -195,7 +209,7 @@ class TestCarlini(TestBase):
     #     logger.info("CW2 Success Rate: %.2f", (sum(target == y_pred_adv) / float(len(target))))
     #
     #     # Second attack
-    #     cl2m = CarliniL2Method(classifier=ptc, targeted=False, max_iter=10)
+    #     cl2m = CarliniL2Method(classifier=ptc, targeted=False, max_iter=10, verbose=False)
     #     x_test_adv = cl2m.generate(x_test)
     #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
     #     self.assertGreaterEqual(np.amin(x_test_adv), 0.0)
@@ -212,7 +226,7 @@ class TestCarlini(TestBase):
 
     # def test_keras_iris_clipped_L2(self):
     #     classifier = get_tabular_classifier_kr()
-    #     attack = CarliniL2Method(classifier, targeted=False, max_iter=10)
+    #     attack = CarliniL2Method(classifier, targeted=False, max_iter=10, verbose=False)
     #     x_test_adv = attack.generate(self.x_test_iris)
     #     self.assertFalse((self.x_test_iris == x_test_adv).all())
     #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
@@ -228,7 +242,7 @@ class TestCarlini(TestBase):
     #
     #     # Recreate a classifier without clip values
     #     classifier = KerasClassifier(model=classifier._model, use_logits=False, channels_first=True)
-    #     attack = CarliniL2Method(classifier, targeted=False, max_iter=10)
+    #     attack = CarliniL2Method(classifier, targeted=False, max_iter=10, verbose=False)
     #     x_test_adv = attack.generate(self.x_test_iris)
     #     self.assertFalse((self.x_test_iris == x_test_adv).all())
     #
@@ -241,7 +255,7 @@ class TestCarlini(TestBase):
     #     classifier, _ = get_tabular_classifier_tf()
     #
     #     # Test untargeted attack
-    #     attack = CarliniL2Method(classifier, targeted=False, max_iter=10)
+    #     attack = CarliniL2Method(classifier, targeted=False, max_iter=10, verbose=False)
     #     x_test_adv = attack.generate(self.x_test_iris)
     #     self.assertFalse((self.x_test_iris == x_test_adv).all())
     #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
@@ -254,7 +268,7 @@ class TestCarlini(TestBase):
     #
     #     # Test targeted attack
     #     targets = random_targets(self.y_test_iris, nb_classes=3)
-    #     attack = CarliniL2Method(classifier, targeted=True, max_iter=10)
+    #     attack = CarliniL2Method(classifier, targeted=True, max_iter=10, verbose=False)
     #     x_test_adv = attack.generate(self.x_test_iris, **{"y": targets})
     #     self.assertFalse((self.x_test_iris == x_test_adv).all())
     #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
@@ -267,7 +281,7 @@ class TestCarlini(TestBase):
 
     # def test_pytorch_iris_L2(self):
     #     classifier = get_tabular_classifier_pt()
-    #     attack = CarliniL2Method(classifier, targeted=False, max_iter=10)
+    #     attack = CarliniL2Method(classifier, targeted=False, max_iter=10, verbose=False)
     #     x_test_adv = attack.generate(self.x_test_iris)
     #     self.assertFalse((self.x_test_iris == x_test_adv).all())
     #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
@@ -297,7 +311,7 @@ class TestCarlini(TestBase):
     #         classifier.fit(x=self.x_test_iris, y=self.y_test_iris)
     #
     #         # Test untargeted attack
-    #         attack = CarliniL2Method(classifier, targeted=False, max_iter=2)
+    #         attack = CarliniL2Method(classifier, targeted=False, max_iter=2, verbose=False)
     #         x_test_adv = attack.generate(self.x_test_iris)
     #         self.assertFalse((self.x_test_iris == x_test_adv).all())
     #         self.assertLessEqual(np.amax(x_test_adv), 1.0)
@@ -313,7 +327,7 @@ class TestCarlini(TestBase):
     #
     #         # Test targeted attack
     #         targets = random_targets(self.y_test_iris, nb_classes=3)
-    #         attack = CarliniL2Method(classifier, targeted=True, max_iter=2)
+    #         attack = CarliniL2Method(classifier, targeted=True, max_iter=2, verbose=False)
     #         x_test_adv = attack.generate(self.x_test_iris, **{"y": targets})
     #         self.assertFalse((self.x_test_iris == x_test_adv).all())
     #         self.assertLessEqual(np.amax(x_test_adv), 1.0)
@@ -330,6 +344,35 @@ class TestCarlini(TestBase):
     #         # Check that x_test has not been modified by attack and classifier
     #         self.assertAlmostEqual(float(np.max(np.abs(x_test_original - self.x_test_iris))), 0.0, delta=0.00001)
 
+    def test_check_params_L2(self):
+
+        ptc = get_image_classifier_pt(from_logits=True)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniL2Method(ptc, binary_search_steps="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniL2Method(ptc, binary_search_steps=-1)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniL2Method(ptc, max_iter="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniL2Method(ptc, max_iter=-1)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniL2Method(ptc, max_halving="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniL2Method(ptc, max_halving=-1)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniL2Method(ptc, max_doubling="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniL2Method(ptc, max_doubling=-1)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniL2Method(ptc, batch_size="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniL2Method(ptc, batch_size=-1)
+
     """
     A unittest class for testing the Carlini LInf attack.
     """
@@ -343,7 +386,7 @@ class TestCarlini(TestBase):
         tfc, sess = get_image_classifier_tf(from_logits=True)
 
         # Failure attack
-        clinfm = CarliniLInfMethod(classifier=tfc, targeted=True, max_iter=0, learning_rate=0, eps=0.5)
+        clinfm = CarliniLInfMethod(classifier=tfc, targeted=True, max_iter=0, learning_rate=0, verbose=False)
         params = {"y": random_targets(self.y_test_mnist, tfc.nb_classes)}
         x_test_adv = clinfm.generate(self.x_test_mnist, **params)
         self.assertLessEqual(np.amax(x_test_adv), 1.0)
@@ -363,7 +406,9 @@ class TestCarlini(TestBase):
         tfc, sess = get_image_classifier_tf(from_logits=True)
 
         # First attack
-        clinfm = CarliniLInfMethod(classifier=tfc, targeted=True, max_iter=10, eps=0.5)
+        clinfm = CarliniLInfMethod(
+            classifier=tfc, targeted=True, max_iter=10, initial_const=1, largest_const=1.1, verbose=False
+        )
         params = {"y": random_targets(self.y_test_mnist, tfc.nb_classes)}
         x_test_adv = clinfm.generate(self.x_test_mnist, **params)
         self.assertFalse((self.x_test_mnist == x_test_adv).all())
@@ -377,7 +422,9 @@ class TestCarlini(TestBase):
         self.assertTrue((target == y_pred_adv).any())
 
         # Second attack, no batching
-        clinfm = CarliniLInfMethod(classifier=tfc, targeted=False, max_iter=10, eps=0.5, batch_size=1)
+        clinfm = CarliniLInfMethod(
+            classifier=tfc, targeted=False, max_iter=10, initial_const=1, largest_const=1.1, verbose=False
+        )
         x_test_adv = clinfm.generate(self.x_test_mnist)
         self.assertLessEqual(np.amax(x_test_adv), 1.0)
         self.assertGreaterEqual(np.amin(x_test_adv), -1e-6)
@@ -406,7 +453,7 @@ class TestCarlini(TestBase):
     #     krc = get_image_classifier_kr(from_logits=True)
     #
     #     # First attack
-    #     clinfm = CarliniLInfMethod(classifier=krc, targeted=True, max_iter=10, eps=0.5)
+    #     clinfm = CarliniLInfMethod(classifier=krc, targeted=True, max_iter=10, verbose=False)
     #     params = {"y": random_targets(self.y_test_mnist, krc.nb_classes)}
     #     x_test_adv = clinfm.generate(self.x_test_mnist, **params)
     #     self.assertFalse((self.x_test_mnist == x_test_adv).all())
@@ -420,7 +467,7 @@ class TestCarlini(TestBase):
     #     self.assertTrue((target == y_pred_adv).any())
     #
     #     # Second attack
-    #     clinfm = CarliniLInfMethod(classifier=krc, targeted=False, max_iter=10, eps=0.5)
+    #     clinfm = CarliniLInfMethod(classifier=krc, targeted=False, max_iter=10, verbose=False)
     #     x_test_adv = clinfm.generate(self.x_test_mnist)
     #     self.assertLessEqual(np.amax(x_test_adv), 1.000001)
     #     self.assertGreaterEqual(np.amin(x_test_adv), -1e-6)
@@ -445,7 +492,7 @@ class TestCarlini(TestBase):
     #     ptc = get_image_classifier_pt(from_logits=True)
     #
     #     # First attack
-    #     clinfm = CarliniLInfMethod(classifier=ptc, targeted=True, max_iter=10, eps=0.5)
+    #     clinfm = CarliniLInfMethod(classifier=ptc, targeted=True, max_iter=10, verbose=False)
     #     params = {"y": random_targets(self.y_test_mnist, ptc.nb_classes)}
     #     x_test_adv = clinfm.generate(x_test, **params)
     #     self.assertFalse((x_test == x_test_adv).all())
@@ -456,7 +503,7 @@ class TestCarlini(TestBase):
     #     self.assertTrue((target == y_pred_adv).any())
     #
     #     # Second attack
-    #     clinfm = CarliniLInfMethod(classifier=ptc, targeted=False, max_iter=10, eps=0.5)
+    #     clinfm = CarliniLInfMethod(classifier=ptc, targeted=False, max_iter=10, verbose=False)
     #     x_test_adv = clinfm.generate(x_test)
     #     self.assertLessEqual(np.amax(x_test_adv), 1.0 + 1e-6)
     #     self.assertGreaterEqual(np.amin(x_test_adv), -1e-6)
@@ -470,7 +517,7 @@ class TestCarlini(TestBase):
 
     # def test_keras_iris_clipped_LInf(self):
     #     classifier = get_tabular_classifier_kr()
-    #     attack = CarliniLInfMethod(classifier, targeted=False, max_iter=10, eps=0.5)
+    #     attack = CarliniLInfMethod(classifier, targeted=False, max_iter=10, verbose=False)
     #     x_test_adv = attack.generate(self.x_test_iris)
     #     self.assertFalse((self.x_test_iris == x_test_adv).all())
     #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
@@ -486,7 +533,7 @@ class TestCarlini(TestBase):
     #
     #     # Recreate a classifier without clip values
     #     classifier = KerasClassifier(model=classifier._model, use_logits=False, channels_first=True)
-    #     attack = CarliniLInfMethod(classifier, targeted=False, max_iter=10, eps=1)
+    #     attack = CarliniLInfMethod(classifier, targeted=False, max_iter=10, verbose=False)
     #     x_test_adv = attack.generate(self.x_test_iris)
     #     self.assertFalse((self.x_test_iris == x_test_adv).all())
     #
@@ -499,7 +546,7 @@ class TestCarlini(TestBase):
     #     classifier, _ = get_tabular_classifier_tf()
     #
     #     # Test untargeted attack
-    #     attack = CarliniLInfMethod(classifier, targeted=False, max_iter=10, eps=0.5)
+    #     attack = CarliniLInfMethod(classifier, targeted=False, max_iter=10, verbose=False)
     #     x_test_adv = attack.generate(self.x_test_iris)
     #     self.assertFalse((self.x_test_iris == x_test_adv).all())
     #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
@@ -512,7 +559,7 @@ class TestCarlini(TestBase):
     #
     #     # Test targeted attack
     #     targets = random_targets(self.y_test_iris, nb_classes=3)
-    #     attack = CarliniLInfMethod(classifier, targeted=True, max_iter=10, eps=0.5)
+    #     attack = CarliniLInfMethod(classifier, targeted=True, max_iter=10, verbose=False)
     #     x_test_adv = attack.generate(self.x_test_iris, **{"y": targets})
     #     self.assertFalse((self.x_test_iris == x_test_adv).all())
     #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
@@ -525,7 +572,7 @@ class TestCarlini(TestBase):
 
     # def test_pytorch_iris_LInf(self):
     #     classifier = get_tabular_classifier_pt()
-    #     attack = CarliniLInfMethod(classifier, targeted=False, max_iter=10, eps=0.5)
+    #     attack = CarliniLInfMethod(classifier, targeted=False, max_iter=10, verbose=False)
     #     x_test_adv = attack.generate(self.x_test_iris.astype(np.float32))
     #     self.assertFalse((self.x_test_iris == x_test_adv).all())
     #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
@@ -555,7 +602,7 @@ class TestCarlini(TestBase):
     #         classifier.fit(x=self.x_test_iris, y=self.y_test_iris)
     #
     #         # Test untargeted attack
-    #         attack = CarliniLInfMethod(classifier, targeted=False, max_iter=10, eps=0.5)
+    #         attack = CarliniLInfMethod(classifier, targeted=False, max_iter=10, verbose=False)
     #         x_test_adv = attack.generate(self.x_test_iris)
     #         self.assertFalse((self.x_test_iris == x_test_adv).all())
     #         self.assertLessEqual(np.amax(x_test_adv), 1.0)
@@ -571,7 +618,7 @@ class TestCarlini(TestBase):
     #
     #         # Test targeted attack
     #         targets = random_targets(self.y_test_iris, nb_classes=3)
-    #         attack = CarliniLInfMethod(classifier, targeted=True, max_iter=10, eps=0.5)
+    #         attack = CarliniLInfMethod(classifier, targeted=True, max_iter=10, verbose=False)
     #         x_test_adv = attack.generate(self.x_test_iris, **{"y": targets})
     #         self.assertFalse((self.x_test_iris == x_test_adv).all())
     #         self.assertLessEqual(np.amax(x_test_adv), 1.0)
@@ -588,6 +635,335 @@ class TestCarlini(TestBase):
     #         # Check that x_test has not been modified by attack and classifier
     #         self.assertAlmostEqual(float(np.max(np.abs(x_test_original - self.x_test_iris))), 0.0, delta=0.00001)
 
+    def test_check_params_LInf(self):
+
+        ptc = get_image_classifier_pt(from_logits=True)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniLInfMethod(ptc, max_iter="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniLInfMethod(ptc, max_iter=-1)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniLInfMethod(ptc, decrease_factor="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniLInfMethod(ptc, decrease_factor=-1)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniLInfMethod(ptc, initial_const="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniLInfMethod(ptc, initial_const=-1)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniLInfMethod(ptc, largest_const="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniLInfMethod(ptc, largest_const=-1)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniLInfMethod(ptc, const_factor="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniLInfMethod(ptc, const_factor=-1)
+
+    """
+    A unittest class for testing the Carlini L0 attack.
+    """
+
+    def test_tensorflow_failure_attack_L0(self):
+        """
+        Test the corner case when attack is failed.
+        :return:
+        """
+        # Build TensorFlowClassifier
+        tfc, sess = get_image_classifier_tf(from_logits=True)
+
+        # Failure attack
+        cl0m = CarliniL0Method(
+            classifier=tfc,
+            targeted=False,
+            max_iter=1,
+            batch_size=10,
+            learning_rate=0.01,
+            binary_search_steps=1,
+            warm_start=True,
+            verbose=False,
+        )
+        params = {"y": random_targets(self.y_test_mnist, tfc.nb_classes)}
+        _ = cl0m.generate(self.x_test_mnist, **params)
+        # self.assertLessEqual(np.amax(x_test_adv), 1.0)
+        # self.assertGreaterEqual(np.amin(x_test_adv), 0.0)
+        # self.assertTrue(np.allclose(self.x_test_mnist, x_test_adv, atol=1e-3))
+
+        # Clean-up session
+        if sess is not None:
+            sess.close()
+
+    def test_tensorflow_mnist_L0(self):
+        """
+        First test with the TensorFlowClassifier.
+        :return:
+        """
+        # Build TensorFlowClassifier
+        tfc, sess = get_image_classifier_tf(from_logits=True)
+
+        # First attack
+        cl0m = CarliniL0Method(
+            classifier=tfc, targeted=True, max_iter=1, batch_size=10, binary_search_steps=1, verbose=False
+        )
+        params = {"y": random_targets(self.y_test_mnist, tfc.nb_classes)}
+        x_test_adv = cl0m.generate(self.x_test_mnist, **params)
+        self.assertFalse((self.x_test_mnist == x_test_adv).all())
+        # self.assertLessEqual(np.amax(x_test_adv), 1.0)
+        # self.assertGreaterEqual(np.amin(x_test_adv), 0.0)
+        target = np.argmax(params["y"], axis=1)
+        # y_pred_adv = np.argmax(tfc.predict(x_test_adv), axis=1)
+        # logger.debug("CW0 Target: %s", target)
+        # logger.debug("CW0 Actual: %s", y_pred_adv)
+        # logger.info("CW0 Success Rate: %.2f", (np.sum(target == y_pred_adv) / float(len(target))))
+        # self.assertTrue((target == y_pred_adv).any())
+
+        # Second attack, no batching
+        cl0m = CarliniL0Method(
+            classifier=tfc, targeted=False, max_iter=1, batch_size=10, binary_search_steps=1, verbose=False
+        )
+        x_test_adv = cl0m.generate(self.x_test_mnist)
+        self.assertLessEqual(np.amax(x_test_adv), 1.0)
+        self.assertGreaterEqual(np.amin(x_test_adv), -1e-6)
+        target = np.argmax(params["y"], axis=1)
+        y_pred_adv = np.argmax(tfc.predict(x_test_adv), axis=1)
+        logger.debug("CW0 Target: %s", target)
+        logger.debug("CW0 Actual: %s", y_pred_adv)
+        logger.info("CW0 Success Rate: %.2f", (np.sum(target != y_pred_adv) / float(len(target))))
+        self.assertTrue((target != y_pred_adv).any())
+
+        # Clean-up session
+        if sess is not None:
+            sess.close()
+
+    # @unittest.skipIf(
+    #     not (int(keras.__version__.split(".")[0]) == 2 and int(keras.__version__.split(".")[1]) >= 3),
+    #     reason="Keras 2.3 or later or TensorFlow-Keras required to support selected combination of loss "
+    #     "function and logits.",
+    # )
+    # def test_keras_mnist_L0(self):
+    #     """
+    #     Second test with the KerasClassifier.
+    #     :return:
+    #     """
+    #     # Build KerasClassifier
+    #     krc = get_image_classifier_kr(from_logits=True)
+    #
+    #     # First attack
+    #     cl0m = CarliniL0Method(classifier=krc, targeted=True, max_iter=10, eps=0.5, verbose=False)
+    #     params = {"y": random_targets(self.y_test_mnist, krc.nb_classes)}
+    #     x_test_adv = cl0m.generate(self.x_test_mnist, **params)
+    #     self.assertFalse((self.x_test_mnist == x_test_adv).all())
+    #     self.assertLessEqual(np.amax(x_test_adv), 1.000001)
+    #     self.assertGreaterEqual(np.amin(x_test_adv), -1e-6)
+    #     target = np.argmax(params["y"], axis=1)
+    #     y_pred_adv = np.argmax(krc.predict(x_test_adv), axis=1)
+    #     logger.debug("CW0 Target: %s", target)
+    #     logger.debug("CW0 Actual: %s", y_pred_adv)
+    #     logger.info("CW0 Success Rate: %.2f", (np.sum(target == y_pred_adv) / float(len(target))))
+    #     self.assertTrue((target == y_pred_adv).any())
+    #
+    #     # Second attack
+    #     cl0m = CarliniL0Method(classifier=krc, targeted=False, max_iter=10, eps=0.5, verbose=False)
+    #     x_test_adv = cl0m.generate(self.x_test_mnist)
+    #     self.assertLessEqual(np.amax(x_test_adv), 1.000001)
+    #     self.assertGreaterEqual(np.amin(x_test_adv), -1e-6)
+    #     target = np.argmax(params["y"], axis=1)
+    #     y_pred_adv = np.argmax(krc.predict(x_test_adv), axis=1)
+    #     logger.debug("CW0 Target: %s", target)
+    #     logger.debug("CW0 Actual: %s", y_pred_adv)
+    #     logger.info("CW0 Success Rate: %.2f", (np.sum(target != y_pred_adv) / float(len(target))))
+    #     self.assertTrue((target != y_pred_adv).any())
+    #
+    #     # Clean-up
+    #     k.clear_session()
+    #
+    # def test_pytorch_mnist_L0(self):
+    #     """
+    #     Third test with the PyTorchClassifier.
+    #     :return:
+    #     """
+    #     x_test = np.reshape(self.x_test_mnist, (self.x_test_mnist.shape[0], 1, 28, 28)).astype(np.float32)
+    #
+    #     # Build PyTorchClassifier
+    #     ptc = get_image_classifier_pt(from_logits=True)
+    #
+    #     # First attack
+    #     cl0m = CarliniL0Method(classifier=ptc, targeted=True, max_iter=10, eps=0.5, verbose=False)
+    #     params = {"y": random_targets(self.y_test_mnist, ptc.nb_classes)}
+    #     x_test_adv = cl0m.generate(x_test, **params)
+    #     self.assertFalse((x_test == x_test_adv).all())
+    #     self.assertLessEqual(np.amax(x_test_adv), 1.0 + 1e-6)
+    #     self.assertGreaterEqual(np.amin(x_test_adv), -1e-6)
+    #     target = np.argmax(params["y"], axis=1)
+    #     y_pred_adv = np.argmax(ptc.predict(x_test_adv), axis=1)
+    #     self.assertTrue((target == y_pred_adv).any())
+    #
+    #     # Second attack
+    #     cl0m = CarliniL0Method(classifier=ptc, targeted=False, max_iter=10, eps=0.5, verbose=False)
+    #     x_test_adv = cl0m.generate(x_test)
+    #     self.assertLessEqual(np.amax(x_test_adv), 1.0 + 1e-6)
+    #     self.assertGreaterEqual(np.amin(x_test_adv), -1e-6)
+    #
+    #     target = np.argmax(params["y"], axis=1)
+    #     y_pred_adv = np.argmax(ptc.predict(x_test_adv), axis=1)
+    #     self.assertTrue((target != y_pred_adv).any())
+
+    def test_classifier_type_check_fail_L0(self):
+        backend_test_classifier_type_check_fail(CarliniL0Method, [BaseEstimator, ClassGradientsMixin])
+
+    # def test_keras_iris_clipped_L0(self):
+    #     classifier = get_tabular_classifier_kr()
+    #     attack = CarliniL0Method(classifier, targeted=False, max_iter=10, eps=0.5, verbose=False)
+    #     x_test_adv = attack.generate(self.x_test_iris)
+    #     self.assertFalse((self.x_test_iris == x_test_adv).all())
+    #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
+    #     self.assertGreaterEqual(np.amin(x_test_adv), 0.0)
+    #
+    #     predictions_adv = np.argmax(classifier.predict(x_test_adv), axis=1)
+    #     self.assertFalse((np.argmax(self.y_test_iris, axis=1) == predictions_adv).all())
+    #     accuracy = np.sum(predictions_adv == np.argmax(self.y_test_iris, axis=1)) / self.y_test_iris.shape[0]
+    #     logger.info("Accuracy on Iris with C&W adversarial examples: %.2f%%", (accuracy * 100))
+    #
+    # def test_keras_iris_unbounded_L0(self):
+    #     classifier = get_tabular_classifier_kr()
+    #
+    #     # Recreate a classifier without clip values
+    #     classifier = KerasClassifier(model=classifier._model, use_logits=False, channels_first=True)
+    #     attack = CarliniL0Method(classifier, targeted=False, max_iter=10, eps=1, verbose=False)
+    #     x_test_adv = attack.generate(self.x_test_iris)
+    #     self.assertFalse((self.x_test_iris == x_test_adv).all())
+    #
+    #     predictions_adv = np.argmax(classifier.predict(x_test_adv), axis=1)
+    #     self.assertFalse((np.argmax(self.y_test_iris, axis=1) == predictions_adv).all())
+    #     accuracy = np.sum(predictions_adv == np.argmax(self.y_test_iris, axis=1)) / self.y_test_iris.shape[0]
+    #     logger.info("Accuracy on Iris with C&W adversarial examples: %.2f%%", (accuracy * 100))
+
+    # def test_tensorflow_iris_L0(self):
+    #     classifier, _ = get_tabular_classifier_tf()
+    #
+    #     # Test untargeted attack
+    #     attack = CarliniL0Method(classifier, targeted=False, max_iter=10, eps=0.5, verbose=False)
+    #     x_test_adv = attack.generate(self.x_test_iris)
+    #     self.assertFalse((self.x_test_iris == x_test_adv).all())
+    #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
+    #     self.assertGreaterEqual(np.amin(x_test_adv), 0.0)
+    #
+    #     predictions_adv = np.argmax(classifier.predict(x_test_adv), axis=1)
+    #     self.assertFalse((np.argmax(self.y_test_iris, axis=1) == predictions_adv).all())
+    #     accuracy = np.sum(predictions_adv == np.argmax(self.y_test_iris, axis=1)) / self.y_test_iris.shape[0]
+    #     logger.info("Accuracy on Iris with C&W adversarial examples: %.2f%%", (accuracy * 100))
+    #
+    #     # Test targeted attack
+    #     targets = random_targets(self.y_test_iris, nb_classes=3)
+    #     attack = CarliniL0Method(classifier, targeted=True, max_iter=10, eps=0.5, verbose=False)
+    #     x_test_adv = attack.generate(self.x_test_iris, **{"y": targets})
+    #     self.assertFalse((self.x_test_iris == x_test_adv).all())
+    #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
+    #     self.assertGreaterEqual(np.amin(x_test_adv), 0.0)
+    #
+    #     predictions_adv = np.argmax(classifier.predict(x_test_adv), axis=1)
+    #     self.assertTrue((np.argmax(targets, axis=1) == predictions_adv).any())
+    #     accuracy = np.sum(predictions_adv == np.argmax(targets, axis=1)) / self.y_test_iris.shape[0]
+    #     logger.info("Success rate of targeted C&W on Iris: %.2f%%", (accuracy * 100))
+
+    # def test_pytorch_iris_L0(self):
+    #     classifier = get_tabular_classifier_pt()
+    #     attack = CarliniL0Method(classifier, targeted=False, max_iter=10, eps=0.5, verbose=False)
+    #     x_test_adv = attack.generate(self.x_test_iris.astype(np.float32))
+    #     self.assertFalse((self.x_test_iris == x_test_adv).all())
+    #     self.assertLessEqual(np.amax(x_test_adv), 1.0)
+    #     self.assertGreaterEqual(np.amin(x_test_adv), 0.0)
+    #
+    #     predictions_adv = np.argmax(classifier.predict(x_test_adv), axis=1)
+    #     self.assertFalse((np.argmax(self.y_test_iris, axis=1) == predictions_adv).all())
+    #     accuracy = np.sum(predictions_adv == np.argmax(self.y_test_iris, axis=1)) / self.y_test_iris.shape[0]
+    #     logger.info("Accuracy on Iris with C&W adversarial examples: %.2f%%", (accuracy * 100))
+
+    # def test_scikitlearn_L0(self):
+    #     from sklearn.linear_model import LogisticRegression
+    #     from sklearn.svm import SVC, LinearSVC
+    #
+    #     from art.estimators.classification.scikitlearn import SklearnClassifier
+    #
+    #     scikitlearn_test_cases = [
+    #         LogisticRegression(solver="lbfgs", multi_class="auto"),
+    #         SVC(gamma="auto"),
+    #         LinearSVC(),
+    #     ]
+    #
+    #     x_test_original = self.x_test_iris.copy()
+    #
+    #     for model in scikitlearn_test_cases:
+    #         classifier = SklearnClassifier(model=model, clip_values=(0, 1))
+    #         classifier.fit(x=self.x_test_iris, y=self.y_test_iris)
+    #
+    #         # Test untargeted attack
+    #         attack = CarliniL0Method(classifier, targeted=False, max_iter=10, eps=0.5, verbose=False)
+    #         x_test_adv = attack.generate(self.x_test_iris)
+    #         self.assertFalse((self.x_test_iris == x_test_adv).all())
+    #         self.assertLessEqual(np.amax(x_test_adv), 1.0)
+    #         self.assertGreaterEqual(np.amin(x_test_adv), 0.0)
+    #
+    #         predictions_adv = np.argmax(classifier.predict(x_test_adv), axis=1)
+    #         self.assertFalse((np.argmax(self.y_test_iris, axis=1) == predictions_adv).all())
+    #         accuracy = np.sum(predictions_adv == np.argmax(self.y_test_iris, axis=1)) / self.y_test_iris.shape[0]
+    #         logger.info(
+    #             "Accuracy of " + classifier.__class__.__name__ + " on Iris with C&W adversarial examples: " "%.2f%%",
+    #             (accuracy * 100),
+    #         )
+    #
+    #         # Test targeted attack
+    #         targets = random_targets(self.y_test_iris, nb_classes=3)
+    #         attack = CarliniL0Method(classifier, targeted=True, max_iter=10, eps=0.5, verbose=False)
+    #         x_test_adv = attack.generate(self.x_test_iris, **{"y": targets})
+    #         self.assertFalse((self.x_test_iris == x_test_adv).all())
+    #         self.assertLessEqual(np.amax(x_test_adv), 1.0)
+    #         self.assertGreaterEqual(np.amin(x_test_adv), 0.0)
+    #
+    #         predictions_adv = np.argmax(classifier.predict(x_test_adv), axis=1)
+    #         self.assertTrue((np.argmax(targets, axis=1) == predictions_adv).any())
+    #         accuracy = np.sum(predictions_adv == np.argmax(targets, axis=1)) / self.y_test_iris.shape[0]
+    #         logger.info(
+    #             "Success rate of " + classifier.__class__.__name__ + " on targeted C&W on Iris: %.2f%%",
+    #             (accuracy * 100),
+    #         )
+    #
+    #         # Check that x_test has not been modified by attack and classifier
+    #         self.assertAlmostEqual(float(np.max(np.abs(x_test_original - self.x_test_iris))), 0.0, delta=0.00001)
+
+    def test_check_params_L0(self):
+
+        ptc = get_image_classifier_pt(from_logits=True)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniL0Method(ptc, binary_search_steps="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniL0Method(ptc, binary_search_steps=-1)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniL0Method(ptc, max_iter="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniL0Method(ptc, max_iter=-1)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniL0Method(ptc, max_halving="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniL0Method(ptc, max_halving=-1)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniL0Method(ptc, max_doubling="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniL0Method(ptc, max_doubling=-1)
+
+        with self.assertRaises(ValueError):
+            _ = CarliniL0Method(ptc, batch_size="1.0")
+        with self.assertRaises(ValueError):
+            _ = CarliniL0Method(ptc, batch_size=-1)
+
 
 if __name__ == "__main__":
     unittest.main()
