@@ -25,7 +25,7 @@ import numpy as np
 
 from art.defences.preprocessor import FeatureSqueezing, JpegCompression, SpatialSmoothing
 
-from tests.utils import TestBase, get_classifier_bb
+from tests.utils import TestBase, get_classifier_bb, get_classifier_bb_nn
 
 logger = logging.getLogger(__name__)
 
@@ -91,7 +91,64 @@ class TestBlackBoxClassifier(TestBase):
         self.assertIn("clip_values=[  0. 255.]", repr_)
         self.assertIn("defences=None", repr_)
         self.assertIn(
-            "preprocessing=[StandardisationMeanStd(mean=0, std=1, apply_fit=True, apply_predict=True)]", repr_
+            "preprocessing=StandardisationMeanStd(mean=0.0, std=1.0, apply_fit=True, apply_predict=True)", repr_
+        )
+
+
+class TestBlackBoxClassifierNeuralNetwork(TestBase):
+    """
+    This class tests the BlackBox Neural Network classifier.
+    """
+
+    @classmethod
+    def setUpClass(cls):
+        super().setUpClass()
+        cls.test_dir = tempfile.mkdtemp()
+
+    def test_fit(self):
+        classifier = get_classifier_bb_nn()
+        self.assertRaises(
+            NotImplementedError,
+            lambda: classifier.fit(self.x_train_mnist, self.y_train_mnist, batch_size=self.batch_size, nb_epochs=2),
+        )
+
+    def test_shapes(self):
+        classifier = get_classifier_bb_nn()
+        predictions = classifier.predict(self.x_test_mnist)
+        self.assertEqual(predictions.shape, self.y_test_mnist.shape)
+        self.assertEqual(classifier.nb_classes, 10)
+        self.assertEqual(predictions.shape, self.y_test_mnist.shape)
+
+    def test_defences_predict(self):
+        clip_values = (0, 1)
+        fs = FeatureSqueezing(clip_values=clip_values, bit_depth=2)
+        jpeg = JpegCompression(clip_values=clip_values, apply_predict=True)
+        smooth = SpatialSmoothing()
+        classifier = get_classifier_bb_nn(defences=[fs, jpeg, smooth])
+        self.assertEqual(len(classifier.preprocessing_defences), 3)
+
+        predictions_classifier = classifier.predict(self.x_test_mnist)
+
+        # Apply the same defences by hand
+        x_test_defense = self.x_test_mnist
+        x_test_defense, _ = fs(x_test_defense, self.y_test_mnist)
+        x_test_defense, _ = jpeg(x_test_defense, self.y_test_mnist)
+        x_test_defense, _ = smooth(x_test_defense, self.y_test_mnist)
+        classifier = get_classifier_bb_nn()
+        predictions_check = classifier.predict(x_test_defense)
+
+        # Check that the prediction results match
+        np.testing.assert_array_almost_equal(predictions_classifier, predictions_check, decimal=4)
+
+    def test_repr(self):
+        classifier = get_classifier_bb_nn()
+        repr_ = repr(classifier)
+
+        self.assertIn("BlackBoxClassifier", repr_)
+        self.assertIn("clip_values=[  0. 255.]", repr_)
+        self.assertIn("defences=None", repr_)
+        self.assertIn(
+            "preprocessing=StandardisationMeanStd(mean=0.0, std=1.0, apply_fit=True, apply_predict=True)", repr_
         )
 
 
